@@ -9,14 +9,17 @@ from .models import *
 
 logger = get_task_logger(__name__)
 
+def chunks(l, n):
+    return [l[i:i+n] for i in range(0, len(l), n)]
+
 @task()
 def doReset():
     lemmas = loadLemmas()
-    lemma_job = group(addLemmas.si().chunks(lemmas,10000))
+    lemma_job = group(addLemmas.si(x) for x in chunks(lemmas,10000))
     wfs,spells,trans = loadWF()
-    wf_job = group(addWFS.si().chunks(wfs,10000))
-    spell_job = group(addSpells.si().chunks(spells,10000))
-    trans_job = group(addTrans.si().chunks(trans,10000))
+    wf_job = group(addWFS.si(x) for x in chunks(wfs,10000))
+    spell_job = group(addSpells.si(x) for x in chunks(spells,10000))
+    trans_job = group(addTrans.si(x) for x in chunks(trans,10000))
     res = chain(loadCats.si(), lemma_job,wf_job,spell_job,trans_job,addRelationships.si(wfs))()
     res.get()
 
